@@ -23,10 +23,10 @@ Library: https://docs.python.org/3/library/logging.html
 
 """
 
-import os, logging, yaml, sys, glob, json, traceback, shutil, math
+import os, logging, yaml, sys, glob, json, traceback, shutil
 from pathlib import Path
 import datetime, time
-import teradata, teradatasql, teradatasqlalchemy
+import teradata, teradatasql #teradatasqlalchemy
 import urllib.parse as urllib
 from urllib.parse import quote_plus as quote_plus
 import pyodbc, pandas as pd
@@ -173,9 +173,23 @@ def get_sqlalchemy_teradata_engine(**kwargs):
     elif kwargs.get('user') is not None:
         user_ = kwargs.get('user')
         
-    edw_engine = create_engine("teradatasql://{host}/?logmech=LDAP&username={username}&password={password}".format(host = quote_plus(kwargs.get('server')),
-                                                                                                                   username = quote_plus(user_),
-                                                                                                                   password = quote_plus(kwargs.get('password')))).connect()
+        
+    if os.name == 'posix': # This is a mac
+        edw_engine = create_engine("teradatasql://{host}/?logmech=LDAP&username={username}&password={password}"
+                                   .format(host = quote_plus(kwargs.get('server')),
+                                           username = quote_plus(user_),
+                                           password = quote_plus(kwargs.get('password')))).connect()
+        
+    else:
+        params_str = urllib.quote("""DRIVER={driver};DBCNAME={host};UID={username};PWD={password};authentication=LDAP;"""
+                           .format(driver = quote_plus(kwargs.get('driver')),
+                                   host = quote_plus(kwargs.get('server')),
+                                   username = quote_plus(user_),
+                                   password = quote_plus(kwargs.get('password'))))  
+        
+        conn_str = 'mssql+pyodbc:///?odbc_connect={params_str}'.format(params_str=params_str)
+        
+        edw_engine = create_engine(conn_str, fast_executemany=True)        
 
     return edw_engine
 
@@ -296,12 +310,24 @@ def get_sqlalchemy_sql_credentials_engine(**kwargs):
         user_ = kwargs.get('userid')
     elif kwargs.get('user') is not None:
         user_ = kwargs.get('user')
-    
-    sql_engine = create_engine("mssql+pymssql://{username}:{password}@{host}/{database}".format(host=quote_plus(kwargs.get('server')),
-                                                                                                database=quote_plus(kwargs.get('database')),
-                                                                                                username=quote_plus(user_),
-                                                                                                password=quote_plus(kwargs.get('password')))).connect()    
-
+        
+    if os.name == 'posix': # This is a mac
+        sql_engine = create_engine("mssql+pymssql://{username}:{password}@{host}/{database}".format(host=quote_plus(kwargs.get('server')),
+                                                                                                    database=quote_plus(kwargs.get('database')),
+                                                                                                    username=quote_plus(user_),
+                                                                                                    password=quote_plus(kwargs.get('password')))).connect()            
+    else:
+        params_str = urllib.quote("""Driver={driver};Server={server};Database={database};Uid={user};Pwd={password};""".format(
+                                                       driver=quote_plus(kwargs.get('driver')),
+                                                       server=quote_plus(kwargs.get('server')),
+                                                       database=quote_plus(kwargs.get('database')),
+                                                       user=quote_plus(user_),
+                                                       password=quote_plus(kwargs.get('password'))))
+               
+        conn_str = 'mssql+pyodbc:///?odbc_connect={params_str}'.format(params_str=params_str)      
+        
+        sql_engine = create_engine(conn_str, fast_executemany=True)
+       
     return sql_engine
 
     
